==> ptv_timetable-0.3.0-py3-none-any.whl: ptv_timetable-0.3.0.dist-info/LICENCE.md <==
# Copyright and licensing
### Source code licence
The source code in this project is licensed under the Apache Licence, version 2.0, which allows anyone to use, copy, modify and distribute the source code in this project, provided that the licence and any copyright notices, and, where you or someone else has modified one or more files before distribution, a notice stating that that person has changed those files, are distributed with the source code. For convenience, a copy of the licence is provided below these notices.

For the purposes of clause 4(a) of the licence for this project, the contributors deem it sufficient for a URL or hyperlink to this licence page or the main licence page at https://www.apache.org/licenses/LICENSE-2.0 to be provided in lieu of the full text of the licence.

**Note that the Apache Licence only applies to the source code and not the data obtained from the APIs.**

### Data licences
Data from the PTV Timetable API is open government data that is separately licensed under the Creative Commons Attribution 4.0 International licence (CC BY 4.0) by the Department of Transport and Planning of Victoria, Australia, which can be found at https://creativecommons.org/licenses/by/4.0/legalcode.en.

Data from the Yarra Trams TramTracker data service is proprietary data by Keolis Downer Rail (KDR) Victoria and their terms of use can be found at https://yarratrams.com.au/terms-conditions.

Data from the V/Line website is proprietary data by V/Line Corporation, a statutory authority of the state government of Victoria and their terms of use can be found at https://www.vline.com.au/Terms-of-use.

**If you need to avoid using data that is not freely licensed, do *not* use the `tramtracker` and `vline` modules.**

---

## Apache Licence
Version 2.0, January 2004<br />
http://www.apache.org/licenses/<br />
This copy of the licence has been edited for style; the original licence terms as linked above prevails in the event of any inconsistency.

### Terms and conditions for use, reproduction and distribution

#### 1. Definitions

In these terms:

- ***licence*** shall mean the terms and conditions for use, reproduction, and distribution as defined by sections 1 through 9 of this document.

- ***licensor*** shall mean the copyright owner or entity authorized by the copyright owner that is granting the licence.

- ***legal entity*** shall mean the union of the acting entity and all other entities that control, are controlled by, or are under common control with that entity. For the purposes of this definition, "control" means:
  - (i) the power, direct or indirect, to cause the direction or management of such entity, whether by contract or otherwise, or
  - (ii) ownership of fifty percent (50%) or more of the outstanding shares, or
  - (iii) beneficial ownership of such entity.

- ***you*** (or ***your***) shall mean an individual or legal entity exercising permissions granted by this licence.

- ***source*** form shall mean the preferred form for making modifications, including but not limited to software source code, documentation source, and configuration files.

- ***object*** form shall mean any form resulting from mechanical transformation or translation of a source form, including but not limited to compiled object code, generated documentation, and conversions to other media types.

- ***work*** shall mean the work of authorship, whether in source or object form, made available under the licence, as indicated by a copyright notice that is included in or attached to the work (an example is provided in the Appendix at https://www.apache.org/licenses/LICENSE-2.0).

- ***derivative works*** shall mean any work, whether in source or object form, that is based on (or derived from) the work and for which the editorial revisions, annotations, elaborations, or other modifications represent, as a whole, an original work of authorship. For the purposes of this licence, derivative works shall not include works that remain separable from, or merely link (or bind by name) to the interfaces of, the work and derivative works thereof.

- ***contribution*** shall mean any work of authorship, including the original version of the work and any modifications or additions to that work or derivative works thereof, that is intentionally submitted to licensor for inclusion in the work by the copyright owner or by an individual or legal entity authorized to submit on behalf of the copyright owner. For the purposes of this definition, "submitted" means any form of electronic, verbal, or written communication sent to the licensor or its representatives, including but not limited to communication on electronic mailing lists, source code control systems, and issue tracking systems that are managed by, or on behalf of, the licensor for the purpose of discussing and improving the Work, but excluding communication that is conspicuously marked or otherwise designated in writing by the copyright owner as "Not a contribution."

- ***contributor*** shall mean licensor and any individual or legal entity on behalf of whom a contribution has been received by licensor and subsequently incorporated within the work.

#### 2. Grant of copyright licence

Subject to the terms and conditions of this licence, each contributor hereby grants to you a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable copyright licence to reproduce, prepare derivative works of, publicly display, publicly perform, sublicense, and distribute the work and such derivative works in source or object form.

#### 3. Grant of patent licence

Subject to the terms and conditions of this licence, each contributor hereby grants to you a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable (except as stated in this section) patent licence to make, have made, use, offer to sell, sell, import, and otherwise transfer the work,
where such licence applies only to those patent claims licensable by such contributor that are necessarily infringed by their contribution(s) alone or by combination of their contribution(s) with the work to which such contribution(s) was submitted. If you institute patent litigation against any entity (including a cross-claim or counterclaim in a lawsuit) alleging that the work or a contribution incorporated within the work constitutes direct or contributory patent infringement, then any patent licences granted to you under this licence for that work shall terminate as of the date such litigation is filed.

#### 4. Redistribution

You may reproduce and distribute copies of the work or derivative works thereof in any medium, with or without modifications, and in source or object form, provided that you meet the following conditions:

- (a) You must give any other recipients of the work or derivative works a copy of this licence; and
- (b) You must cause any modified files to carry prominent notices stating that you changed the files; and
- (c) You must retain, in the source form of any derivative works that you distribute, all copyright, patent, trademark, and attribution notices from the source form of the work, excluding those notices that do not pertain to any part of the derivative works; and
- (d) If the work includes a "NOTICE" text file as part of its distribution, then any derivative works that you distribute must include a readable copy of the attribution notices contained within such NOTICE file, excluding those notices that do not pertain to any part of the derivative works, in at least one of the following places: within a NOTICE text file distributed as part of the derivative works; within the source form or documentation, if provided along with the derivative works; or, within a display generated by the derivative works, if and wherever such third-party notices normally appear. The contents of the NOTICE file are for informational purposes only and do not modify the licence. You may add your own attribution notices within derivative works that you distribute, alongside or as an addendum to the NOTICE text from the work, provided that such additional attribution notices cannot be construed as modifying the licence.

You may add your own copyright statement to your modifications and may provide additional or different licence terms and conditions for use, reproduction, or distribution of your modifications, or for any such derivative works as a whole, provided your use, reproduction, and distribution of the work otherwise complies with the conditions stated in this licence.

#### 5. Submission of contributions

Unless you explicitly state otherwise, any contribution intentionally submitted for inclusion in the work
by you to the licensor shall be under the terms and conditions of this licence, without any additional terms or conditions. Notwithstanding the above, nothing herein shall supersede or modify the terms of any separate licence agreement you may have executed with licensor regarding such contributions.

#### 6. Trademarks

This licence does not grant permission to use the trade names, trademarks, service marks, or product names of the licensor, except as required for reasonable and customary use in describing the origin of the work and reproducing the content of the NOTICE file.

#### 7. Disclaimer of warranty

Unless required by applicable law or agreed to in writing, the licensor provides the work (and each contributor provides its contributions) on an **"as is" basis, without warranties or conditions of any kind**, either express or implied, including, without limitation, any warranties or conditions of **title, non-infringement, merchantability, or fitness for a particular purpose**. You are solely responsible for determining the appropriateness of using or redistributing the work and assume any risks associated with your exercise of permissions under this licence.

#### 8. Limitation of liability

In no event and under no legal theory, whether in tort (including negligence), contract, or otherwise, unless required by applicable law (such as deliberate and grossly negligent acts) or agreed to in writing, shall any contributor be liable to you for damages, including any direct, indirect, special, incidental, or consequential damages of any character arising as a result of this licence or out of the use or inability to use the work (including but not limited to damages for loss of goodwill, work stoppage, computer failure or malfunction, or any and all other commercial damages or losses), even if such contributor has been advised of the possibility of such damages.

#### 9. Accepting warranty or additional liability

While redistributing the work or derivative works thereof, you may choose to offer, and charge a fee for, acceptance of support, warranty, indemnity, or other liability obligations and/or rights consistent with this licence. However, in accepting such obligations, you may act only on your own behalf and on your sole responsibility, not on behalf of any other contributor, and only if You agree to indemnify, defend, and hold each contributor harmless for any liability incurred by, or claims asserted against, such contributor by reason of your accepting any such warranty or additional liability.

==> ptv_timetable-0.4.0-py3-none-any.whl: ptv_timetable-0.4.0.dist-info/LICENCE.md <==
# Copyright and licensing
### Source code licence
The source code in this project is licensed under the Apache Licence, version 2.0, which allows anyone to use, copy, modify and distribute the source code in this project, provided that the licence and any copyright notices, and, where you or someone else has modified one or more files before distribution, a notice stating that that person has changed those files, are distributed with the source code. For convenience, a copy of the licence is provided below these notices.

For the purposes of clause 4(a) of the licence for this project, the contributors deem it sufficient for a URL or hyperlink to this licence page or the main licence page at https://www.apache.org/licenses/LICENSE-2.0 to be provided in lieu of the full text of the licence.

**Note that the Apache Licence only applies to the source code and not the data obtained from the APIs.**

### Data licences
Data from the PTV Timetable API is open government data that is separately licensed under the Creative Commons Attribution 4.0 International licence (CC BY 4.0) by the Department of Transport and Planning of Victoria, Australia, which can be found at https://creativecommons.org/licenses/by/4.0/legalcode.en.

Data from the Yarra Trams TramTracker service is proprietary data by Yarra Journey Makers Pty Ltd and their terms of use can be found at https://yarratrams.com.au/terms-conditions.

Data from the V/Line website is proprietary data by V/Line Corporation, a statutory authority of the state government of Victoria and their terms of use can be found at https://www.vline.com.au/Terms-of-use.

**If you need to avoid using data that is not freely licensed, do *not* use the `tramtracker` and `vline` modules.**

---

## Apache Licence
Version 2.0, January 2004<br />
http://www.apache.org/licenses/<br />
This copy of the licence has been edited for style; the original licence terms as linked above prevails in the event of any inconsistency.

### Terms and conditions for use, reproduction and distribution

#### 1. Definitions

In these terms:

- ***licence*** shall mean the terms and conditions for use, reproduction, and distribution as defined by sections 1 through 9 of this document.

- ***licensor*** shall mean the copyright owner or entity authorized by the copyright owner that is granting the licence.

- ***legal entity*** shall mean the union of the acting entity and all other entities that control, are controlled by, or are under common control with that entity. For the purposes of this definition, "control" means:
  - (i) the power, direct or indirect, to cause the direction or management of such entity, whether by contract or otherwise, or
  - (ii) ownership of fifty percent (50%) or more of the outstanding shares, or
  - (iii) beneficial ownership of such entity.

- ***you*** (or ***your***) shall mean an individual or legal entity exercising permissions granted by this licence.

- ***source*** form shall mean the preferred form for making modifications, including but not limited to software source code, documentation source, and configuration files.

- ***object*** form shall mean any form resulting from mechanical transformation or translation of a source form, including but not limited to compiled object code, generated documentation, and conversions to other media types.

- ***work*** shall mean the work of authorship, whether in source or object form, made available under the licence, as indicated by a copyright notice that is included in or attached to the work (an example is provided in the Appendix at https://www.apache.org/licenses/LICENSE-2.0).

- ***derivative works*** shall mean any work, whether in source or object form, that is based on (or derived from) the work and for which the editorial revisions, annotations, elaborations, or other modifications represent, as a whole, an original work of authorship. For the purposes of this licence, derivative works shall not include works that remain separable from, or merely link (or bind by name) to the interfaces of, the work and derivative works thereof.

- ***contribution*** shall mean any work of authorship, including the original version of the work and any modifications or additions to that work or derivative works thereof, that is intentionally submitted to licensor for inclusion in the work by the copyright owner or by an individual or legal entity authorized to submit on behalf of the copyright owner. For the purposes of this definition, "submitted" means any form of electronic, verbal, or written communication sent to the licensor or its representatives, including but not limited to communication on electronic mailing lists, source code control systems, and issue tracking systems that are managed by, or on behalf of, the licensor for the purpose of discussing and improving the Work, but excluding communication that is conspicuously marked or otherwise designated in writing by the copyright owner as "Not a contribution."

- ***contributor*** shall mean licensor and any individual or legal entity on behalf of whom a contribution has been received by licensor and subsequently incorporated within the work.

#### 2. Grant of copyright licence

Subject to the terms and conditions of this licence, each contributor hereby grants to you a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable copyright licence to reproduce, prepare derivative works of, publicly display, publicly perform, sublicense, and distribute the work and such derivative works in source or object form.

#### 3. Grant of patent licence

Subject to the terms and conditions of this licence, each contributor hereby grants to you a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable (except as stated in this section) patent licence to make, have made, use, offer to sell, sell, import, and otherwise transfer the work,
where such licence applies only to those patent claims licensable by such contributor that are necessarily infringed by their contribution(s) alone or by combination of their contribution(s) with the work to which such contribution(s) was submitted. If you institute patent litigation against any entity (including a cross-claim or counterclaim in a lawsuit) alleging that the work or a contribution incorporated within the work constitutes direct or contributory patent infringement, then any patent licences granted to you under this licence for that work shall terminate as of the date such litigation is filed.

#### 4. Redistribution

You may reproduce and distribute copies of the work or derivative works thereof in any medium, with or without modifications, and in source or object form, provided that you meet the following conditions:

- (a) You must give any other recipients of the work or derivative works a copy of this licence; and
- (b) You must cause any modified files to carry prominent notices stating that you changed the files; and
- (c) You must retain, in the source form of any derivative works that you distribute, all copyright, patent, trademark, and attribution notices from the source form of the work, excluding those notices that do not pertain to any part of the derivative works; and
- (d) If the work includes a "NOTICE" text file as part of its distribution, then any derivative works that you distribute must include a readable copy of the attribution notices contained within such NOTICE file, excluding those notices that do not pertain to any part of the derivative works, in at least one of the following places: within a NOTICE text file distributed as part of the derivative works; within the source form or documentation, if provided along with the derivative works; or, within a display generated by the derivative works, if and wherever such third-party notices normally appear. The contents of the NOTICE file are for informational purposes only and do not modify the licence. You may add your own attribution notices within derivative works that you distribute, alongside or as an addendum to the NOTICE text from the work, provided that such additional attribution notices cannot be construed as modifying the licence.

You may add your own copyright statement to your modifications and may provide additional or different licence terms and conditions for use, reproduction, or distribution of your modifications, or for any such derivative works as a whole, provided your use, reproduction, and distribution of the work otherwise complies with the conditions stated in this licence.

#### 5. Submission of contributions

Unless you explicitly state otherwise, any contribution intentionally submitted for inclusion in the work
by you to the licensor shall be under the terms and conditions of this licence, without any additional terms or conditions. Notwithstanding the above, nothing herein shall supersede or modify the terms of any separate licence agreement you may have executed with licensor regarding such contributions.

#### 6. Trademarks

This licence does not grant permission to use the trade names, trademarks, service marks, or product names of the licensor, except as required for reasonable and customary use in describing the origin of the work and reproducing the content of the NOTICE file.

#### 7. Disclaimer of warranty

Unless required by applicable law or agreed to in writing, the licensor provides the work (and each contributor provides its contributions) on an **"as is" basis, without warranties or conditions of any kind**, either express or implied, including, without limitation, any warranties or conditions of **title, non-infringement, merchantability, or fitness for a particular purpose**. You are solely responsible for determining the appropriateness of using or redistributing the work and assume any risks associated with your exercise of permissions under this licence.

#### 8. Limitation of liability

In no event and under no legal theory, whether in tort (including negligence), contract, or otherwise, unless required by applicable law (such as deliberate and grossly negligent acts) or agreed to in writing, shall any contributor be liable to you for damages, including any direct, indirect, special, incidental, or consequential damages of any character arising as a result of this licence or out of the use or inability to use the work (including but not limited to damages for loss of goodwill, work stoppage, computer failure or malfunction, or any and all other commercial damages or losses), even if such contributor has been advised of the possibility of such damages.

#### 9. Accepting warranty or additional liability

While redistributing the work or derivative works thereof, you may choose to offer, and charge a fee for, acceptance of support, warranty, indemnity, or other liability obligations and/or rights consistent with this licence. However, in accepting such obligations, you may act only on your own behalf and on your sole responsibility, not on behalf of any other contributor, and only if You agree to indemnify, defend, and hold each contributor harmless for any liability incurred by, or claims asserted against, such contributor by reason of your accepting any such warranty or additional liability.
